"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from syllable_sdk import errors, models, utils
from syllable_sdk._hooks import HookContext
from syllable_sdk.types import BaseModel, OptionalNullable, UNSET
from syllable_sdk.utils import get_security_from_env
from syllable_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional, Union, cast


class Batches(BaseSDK):
    r"""Operations related to outbound campaign batches"""

    def list(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.BatchProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.BatchProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.BatchProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseCommunicationBatch:
        r"""List Outbound Communication Batches

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchListRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request(
            method="GET",
            path="/api/v1/outbound/batches",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_list",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListResponseCommunicationBatch, http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.BatchProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.BatchProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.BatchProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseCommunicationBatch:
        r"""List Outbound Communication Batches

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchListRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v1/outbound/batches",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_list",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListResponseCommunicationBatch, http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def create(
        self,
        *,
        request: Union[
            models.CommunicationBatchInput, models.CommunicationBatchInputTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CommunicationBatch:
        r"""Create Outbound Communication Batch

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CommunicationBatchInput)
        request = cast(models.CommunicationBatchInput, request)

        req = self._build_request(
            method="POST",
            path="/api/v1/outbound/batches",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.CommunicationBatchInput
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_create",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CommunicationBatch, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        request: Union[
            models.CommunicationBatchInput, models.CommunicationBatchInputTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CommunicationBatch:
        r"""Create Outbound Communication Batch

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CommunicationBatchInput)
        request = cast(models.CommunicationBatchInput, request)

        req = self._build_request_async(
            method="POST",
            path="/api/v1/outbound/batches",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.CommunicationBatchInput
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_create",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CommunicationBatch, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def get_by_id(
        self,
        *,
        batch_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.BatchDetails:
        r"""Get Outbound Communication Batch

        :param batch_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchGetByIDRequest(
            batch_id=batch_id,
        )

        req = self._build_request(
            method="GET",
            path="/api/v1/outbound/batches/{batch_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_get_by_id",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.BatchDetails, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def get_by_id_async(
        self,
        *,
        batch_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.BatchDetails:
        r"""Get Outbound Communication Batch

        :param batch_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchGetByIDRequest(
            batch_id=batch_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v1/outbound/batches/{batch_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_get_by_id",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.BatchDetails, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def update(
        self,
        *,
        batch_id: str,
        communication_batch_update: Union[
            models.CommunicationBatchUpdate, models.CommunicationBatchUpdateTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CommunicationBatch:
        r"""Update Outbound Communication Batch

        :param batch_id:
        :param communication_batch_update:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchUpdateRequest(
            batch_id=batch_id,
            communication_batch_update=utils.get_pydantic_model(
                communication_batch_update, models.CommunicationBatchUpdate
            ),
        )

        req = self._build_request(
            method="PUT",
            path="/api/v1/outbound/batches/{batch_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.communication_batch_update,
                False,
                False,
                "json",
                models.CommunicationBatchUpdate,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_update",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CommunicationBatch, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        batch_id: str,
        communication_batch_update: Union[
            models.CommunicationBatchUpdate, models.CommunicationBatchUpdateTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CommunicationBatch:
        r"""Update Outbound Communication Batch

        :param batch_id:
        :param communication_batch_update:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchUpdateRequest(
            batch_id=batch_id,
            communication_batch_update=utils.get_pydantic_model(
                communication_batch_update, models.CommunicationBatchUpdate
            ),
        )

        req = self._build_request_async(
            method="PUT",
            path="/api/v1/outbound/batches/{batch_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.communication_batch_update,
                False,
                False,
                "json",
                models.CommunicationBatchUpdate,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_update",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CommunicationBatch, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        batch_id: str,
        body_outbound_batch_delete: Union[
            models.BodyOutboundBatchDelete, models.BodyOutboundBatchDeleteTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Delete Outbound Communication Batch

        :param batch_id:
        :param body_outbound_batch_delete:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchDeleteRequest(
            batch_id=batch_id,
            body_outbound_batch_delete=utils.get_pydantic_model(
                body_outbound_batch_delete, models.BodyOutboundBatchDelete
            ),
        )

        req = self._build_request(
            method="DELETE",
            path="/api/v1/outbound/batches/{batch_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body_outbound_batch_delete,
                False,
                False,
                "form",
                models.BodyOutboundBatchDelete,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        batch_id: str,
        body_outbound_batch_delete: Union[
            models.BodyOutboundBatchDelete, models.BodyOutboundBatchDeleteTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Delete Outbound Communication Batch

        :param batch_id:
        :param body_outbound_batch_delete:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchDeleteRequest(
            batch_id=batch_id,
            body_outbound_batch_delete=utils.get_pydantic_model(
                body_outbound_batch_delete, models.BodyOutboundBatchDelete
            ),
        )

        req = self._build_request_async(
            method="DELETE",
            path="/api/v1/outbound/batches/{batch_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body_outbound_batch_delete,
                False,
                False,
                "form",
                models.BodyOutboundBatchDelete,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def upload(
        self,
        *,
        batch_id: str,
        body_outbound_batch_upload: Optional[
            Union[
                models.BodyOutboundBatchUpload, models.BodyOutboundBatchUploadTypedDict
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Upload Outbound Communication Batch

        :param batch_id:
        :param body_outbound_batch_upload:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchUploadRequest(
            batch_id=batch_id,
            body_outbound_batch_upload=utils.get_pydantic_model(
                body_outbound_batch_upload, Optional[models.BodyOutboundBatchUpload]
            ),
        )

        req = self._build_request(
            method="POST",
            path="/api/v1/outbound/batches/{batch_id}/upload_batch",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body_outbound_batch_upload,
                False,
                True,
                "multipart",
                Optional[models.BodyOutboundBatchUpload],
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_upload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def upload_async(
        self,
        *,
        batch_id: str,
        body_outbound_batch_upload: Optional[
            Union[
                models.BodyOutboundBatchUpload, models.BodyOutboundBatchUploadTypedDict
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Upload Outbound Communication Batch

        :param batch_id:
        :param body_outbound_batch_upload:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchUploadRequest(
            batch_id=batch_id,
            body_outbound_batch_upload=utils.get_pydantic_model(
                body_outbound_batch_upload, Optional[models.BodyOutboundBatchUpload]
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/api/v1/outbound/batches/{batch_id}/upload_batch",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body_outbound_batch_upload,
                False,
                True,
                "multipart",
                Optional[models.BodyOutboundBatchUpload],
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_upload",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def results(
        self,
        *,
        batch_id: str,
        reference_id: OptionalNullable[str] = UNSET,
        status: OptionalNullable[str] = UNSET,
        insights_status: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.CommunicationRequestResult]:
        r"""Fetch Outbound Communication Batch Results

        :param batch_id:
        :param reference_id:
        :param status:
        :param insights_status:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchResultsRequest(
            batch_id=batch_id,
            reference_id=reference_id,
            status=status,
            insights_status=insights_status,
        )

        req = self._build_request(
            method="GET",
            path="/api/v1/outbound/batches/{batch_id}/results",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_results",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                List[models.CommunicationRequestResult], http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def results_async(
        self,
        *,
        batch_id: str,
        reference_id: OptionalNullable[str] = UNSET,
        status: OptionalNullable[str] = UNSET,
        insights_status: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.CommunicationRequestResult]:
        r"""Fetch Outbound Communication Batch Results

        :param batch_id:
        :param reference_id:
        :param status:
        :param insights_status:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchResultsRequest(
            batch_id=batch_id,
            reference_id=reference_id,
            status=status,
            insights_status=insights_status,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v1/outbound/batches/{batch_id}/results",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_results",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                List[models.CommunicationRequestResult], http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def add(
        self,
        *,
        batch_id: str,
        communication_request: Union[
            models.CommunicationRequest, models.CommunicationRequestTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Create Outbound Communication Request

        :param batch_id:
        :param communication_request:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchAddRequest(
            batch_id=batch_id,
            communication_request=utils.get_pydantic_model(
                communication_request, models.CommunicationRequest
            ),
        )

        req = self._build_request(
            method="POST",
            path="/api/v1/outbound/batches/{batch_id}/requests",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.communication_request,
                False,
                False,
                "json",
                models.CommunicationRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_add",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def add_async(
        self,
        *,
        batch_id: str,
        communication_request: Union[
            models.CommunicationRequest, models.CommunicationRequestTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Create Outbound Communication Request

        :param batch_id:
        :param communication_request:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchAddRequest(
            batch_id=batch_id,
            communication_request=utils.get_pydantic_model(
                communication_request, models.CommunicationRequest
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/api/v1/outbound/batches/{batch_id}/requests",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.communication_request,
                False,
                False,
                "json",
                models.CommunicationRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_add",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def remove(
        self,
        *,
        batch_id: str,
        request_body: List[str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Delete Requests By List Of Reference Ids

        :param batch_id:
        :param request_body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchRemoveRequest(
            batch_id=batch_id,
            request_body=request_body,
        )

        req = self._build_request(
            method="POST",
            path="/api/v1/outbound/batches/{batch_id}/remove-requests",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", List[str]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_remove",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def remove_async(
        self,
        *,
        batch_id: str,
        request_body: List[str],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Delete Requests By List Of Reference Ids

        :param batch_id:
        :param request_body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.OutboundBatchRemoveRequest(
            batch_id=batch_id,
            request_body=request_body,
        )

        req = self._build_request_async(
            method="POST",
            path="/api/v1/outbound/batches/{batch_id}/remove-requests",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", List[str]
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="outbound_batch_remove",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .toolparametertransformcondition import (
    ToolParameterTransformCondition,
    ToolParameterTransformConditionTypedDict,
)
from enum import Enum
import pydantic
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Any, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Action(str, Enum):
    r"""The action to perform on the tool parameter value: `default` means only set the value (using the `format` field) if the parameter doesn't exist or is empty, `override` means always set the value,\" and `remove` means \"remove the parameter value.\" """

    DEFAULT = "default"
    OVERRIDE = "override"
    REMOVE = "remove"


class ToolParameterTransformTypedDict(TypedDict):
    r"""A transform to be applied to the value of a tool parameter.

    Either `value` or `format` must be set:
    - `value` is any arbitrary value: string, list or dictionary.
    - `format` is a string composed of other parameters or context variables.
    """

    action: NotRequired[Action]
    r"""The action to perform on the tool parameter value: `default` means only set the value (using the `format` field) if the parameter doesn't exist or is empty, `override` means always set the value,\" and `remove` means \"remove the parameter value.\" """
    when: NotRequired[Nullable[ToolParameterTransformConditionTypedDict]]
    r"""Only apply the transform if the condition is met."""
    value: NotRequired[Nullable[Any]]
    r"""The default value to use for the parameter."""
    format_: NotRequired[Nullable[str]]
    r"""The string value to use for the parameter. The value will be evaluated with the Python `str.format` method, for example, `Hello, {name}!`"""


class ToolParameterTransform(BaseModel):
    r"""A transform to be applied to the value of a tool parameter.

    Either `value` or `format` must be set:
    - `value` is any arbitrary value: string, list or dictionary.
    - `format` is a string composed of other parameters or context variables.
    """

    action: Optional[Action] = Action.DEFAULT
    r"""The action to perform on the tool parameter value: `default` means only set the value (using the `format` field) if the parameter doesn't exist or is empty, `override` means always set the value,\" and `remove` means \"remove the parameter value.\" """

    when: OptionalNullable[ToolParameterTransformCondition] = UNSET
    r"""Only apply the transform if the condition is met."""

    value: OptionalNullable[Any] = UNSET
    r"""The default value to use for the parameter."""

    format_: Annotated[OptionalNullable[str], pydantic.Field(alias="format")] = UNSET
    r"""The string value to use for the parameter. The value will be evaluated with the Python `str.format` method, for example, `Hello, {name}!`"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["action", "when", "value", "format"]
        nullable_fields = ["when", "value", "format"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .statictoolparametertype import StaticToolParameterType
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Any
from typing_extensions import NotRequired, TypedDict


class StaticToolParameterTypedDict(TypedDict):
    r"""A parameter for the tool whose value should be set at config time."""

    name: str
    r"""The name of the parameter - must be unique within the tool."""
    required: bool
    r"""Whether the parameter is required to have a value assigned."""
    type: StaticToolParameterType
    r"""The expected type for a static tool parameter."""
    description: NotRequired[Nullable[str]]
    r"""The description of the parameter."""
    default: NotRequired[Nullable[Any]]
    r"""The default value for the parameter. If `type` is string, must be a string. If `type` is int, must be an int. If `type` is boolean, must be a boolean. If `type` is data_source_list, must be a list of strings (data source names)."""


class StaticToolParameter(BaseModel):
    r"""A parameter for the tool whose value should be set at config time."""

    name: str
    r"""The name of the parameter - must be unique within the tool."""

    required: bool
    r"""Whether the parameter is required to have a value assigned."""

    type: StaticToolParameterType
    r"""The expected type for a static tool parameter."""

    description: OptionalNullable[str] = UNSET
    r"""The description of the parameter."""

    default: OptionalNullable[Any] = UNSET
    r"""The default value for the parameter. If `type` is string, must be a string. If `type` is int, must be an int. If `type` is boolean, must be a boolean. If `type` is data_source_list, must be a list of strings (data source names)."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["description", "default"]
        nullable_fields = ["description", "default"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceModel(str, Enum):
    r"""Model for an agent voice."""

    CHIRP_3_HD = "Chirp 3 HD"
    ELEVEN_FLASH_V2_5 = "eleven_flash_v2_5"
    NEURAL2 = "Neural2"
    STANDARD = "Standard"
    STUDIO = "Studio"
    WAVE_NET = "WaveNet"
    TTS_1 = "tts-1"
    GPT_4O_MINI_TTS = "gpt-4o-mini-tts"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .latencyentry import LatencyEntry, LatencyEntryTypedDict
from .summaryentry import SummaryEntry, SummaryEntryTypedDict
from syllable_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class InspectLatencyResponseTypedDict(TypedDict):
    r"""This is a report of the time spent in each operation during this session. It contains a timeline,
    which lists the operations in the order they were executed, and a summary, which aggregates the
    operations by category and sub-category.
    """

    session_id: str
    timeline: List[LatencyEntryTypedDict]
    summary: NotRequired[List[SummaryEntryTypedDict]]


class InspectLatencyResponse(BaseModel):
    r"""This is a report of the time spent in each operation during this session. It contains a timeline,
    which lists the operations in the order they were executed, and a summary, which aggregates the
    operations by category and sub-category.
    """

    session_id: str

    timeline: List[LatencyEntry]

    summary: Optional[List[SummaryEntry]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .targetmodes import TargetModes
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChannelTargetCreateRequestTypedDict(TypedDict):
    r"""Request model to create a channel target."""

    agent_id: int
    r"""The internal ID of the agent associated with the channel target"""
    channel_id: int
    r"""The internal ID of the channel associated with the channel target"""
    target: str
    r"""The name of the channel target. Must correspond to an organization-level target (available targets can be fetched from `/channels/available-targets`)."""
    target_mode: TargetModes
    r"""Available modes (communication methods) for channel targets."""
    fallback_target: NotRequired[Nullable[str]]
    r"""The fallback for the channel target (currently only supported for \"voice\" mode)"""
    is_test: NotRequired[bool]
    r"""Whether the channel target is intended for testing. If true, any sessions created through this target will be labeled as a test session (i.e., will not be included in dashboard data and can easily be filtered out in the Sessions screen in the SyllableConsole)."""


class ChannelTargetCreateRequest(BaseModel):
    r"""Request model to create a channel target."""

    agent_id: int
    r"""The internal ID of the agent associated with the channel target"""

    channel_id: int
    r"""The internal ID of the channel associated with the channel target"""

    target: str
    r"""The name of the channel target. Must correspond to an organization-level target (available targets can be fetched from `/channels/available-targets`)."""

    target_mode: TargetModes
    r"""Available modes (communication methods) for channel targets."""

    fallback_target: OptionalNullable[str] = UNSET
    r"""The fallback for the channel target (currently only supported for \"voice\" mode)"""

    is_test: Optional[bool] = False
    r"""Whether the channel target is intended for testing. If true, any sessions created through this target will be labeled as a test session (i.e., will not be included in dashboard data and can easily be filtered out in the Sessions screen in the SyllableConsole)."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["fallback_target", "is_test"]
        nullable_fields = ["fallback_target"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .batchstatus import BatchStatus
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class BatchDetailsTypedDict(TypedDict):
    batch_id: str
    r"""Unique ID for conversation batch"""
    campaign_id: int
    r"""Unique ID for campaign"""
    last_updated_by: str
    r"""Email of user who last updated campaign"""
    expires_on: NotRequired[Nullable[datetime]]
    r"""Timestamp of batch expiration"""
    paused: NotRequired[Nullable[bool]]
    r"""Whether the batch is on HOLD. When on HOLD, no outreach will be made."""
    status: NotRequired[BatchStatus]
    r"""Status of a communication batch."""
    upload_filename: NotRequired[Nullable[str]]
    r"""Name of file used to create batch"""
    created_at: NotRequired[datetime]
    r"""Timestamp of batch creation"""
    deleted_at: NotRequired[Nullable[datetime]]
    r"""Timestamp of batch deletion"""
    deleted_reason: NotRequired[Nullable[str]]
    r"""Reason for batch deletion"""
    last_updated_at: NotRequired[Nullable[datetime]]
    r"""Timestamp of last change to batch"""
    error_message: NotRequired[Nullable[str]]
    r"""Error message if batch upload failed"""
    status_counts: NotRequired[Nullable[Dict[str, int]]]
    r"""Counts of requests by status"""


class BatchDetails(BaseModel):
    batch_id: str
    r"""Unique ID for conversation batch"""

    campaign_id: int
    r"""Unique ID for campaign"""

    last_updated_by: str
    r"""Email of user who last updated campaign"""

    expires_on: OptionalNullable[datetime] = UNSET
    r"""Timestamp of batch expiration"""

    paused: OptionalNullable[bool] = UNSET
    r"""Whether the batch is on HOLD. When on HOLD, no outreach will be made."""

    status: Optional[BatchStatus] = None
    r"""Status of a communication batch."""

    upload_filename: OptionalNullable[str] = UNSET
    r"""Name of file used to create batch"""

    created_at: Optional[datetime] = None
    r"""Timestamp of batch creation"""

    deleted_at: OptionalNullable[datetime] = UNSET
    r"""Timestamp of batch deletion"""

    deleted_reason: OptionalNullable[str] = UNSET
    r"""Reason for batch deletion"""

    last_updated_at: OptionalNullable[datetime] = UNSET
    r"""Timestamp of last change to batch"""

    error_message: OptionalNullable[str] = UNSET
    r"""Error message if batch upload failed"""

    status_counts: OptionalNullable[Dict[str, int]] = UNSET
    r"""Counts of requests by status"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "expires_on",
            "paused",
            "status",
            "upload_filename",
            "created_at",
            "deleted_at",
            "deleted_reason",
            "last_updated_at",
            "error_message",
            "status_counts",
        ]
        nullable_fields = [
            "expires_on",
            "paused",
            "upload_filename",
            "deleted_at",
            "deleted_reason",
            "last_updated_at",
            "error_message",
            "status_counts",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AvailableTargetProperties(str, Enum):
    r"""Names of target fields supported for filtering/sorting on available targets list endpoint."""

    CHANNEL_ID = "channel_id"
    CHANNEL_NAME = "channel_name"
    TARGET = "target"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .insightworkflowestimate import (
    InsightWorkflowEstimate,
    InsightWorkflowEstimateTypedDict,
)
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class InsightWorkflowActivateTypedDict(TypedDict):
    r"""Request model to activate an insight workflow."""

    is_acknowledged: bool
    r"""Flag to indicate if the user has acknowledged the estimate"""
    estimate: InsightWorkflowEstimateTypedDict
    r"""Response model for an insight workflow."""


class InsightWorkflowActivate(BaseModel):
    r"""Request model to activate an insight workflow."""

    is_acknowledged: bool
    r"""Flag to indicate if the user has acknowledged the estimate"""

    estimate: InsightWorkflowEstimate
    r"""Response model for an insight workflow."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .body_outbound_batch_upload import (
    BodyOutboundBatchUpload,
    BodyOutboundBatchUploadTypedDict,
)
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class OutboundBatchUploadRequestTypedDict(TypedDict):
    batch_id: str
    body_outbound_batch_upload: NotRequired[BodyOutboundBatchUploadTypedDict]


class OutboundBatchUploadRequest(BaseModel):
    batch_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body_outbound_batch_upload: Annotated[
        Optional[BodyOutboundBatchUpload],
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TargetModes(str, Enum):
    r"""Available modes (communication methods) for channel targets."""

    VOICE = "voice"
    CHAT = "chat"
    SMS = "sms"
    EMAIL = "email"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sessionmessage import SessionMessage, SessionMessageTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionDataTypedDict(TypedDict):
    session_id: int
    r"""Session ID"""
    source: str
    r"""Session source"""
    target: str
    r"""Session target"""
    is_test: bool
    r"""Is test session"""
    messages: List[SessionMessageTypedDict]
    r"""Session messages"""


class SessionData(BaseModel):
    session_id: int
    r"""Session ID"""

    source: str
    r"""Session source"""

    target: str
    r"""Session target"""

    is_test: bool
    r"""Is test session"""

    messages: List[SessionMessage]
    r"""Session messages"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class ToolFunctionTypedDict(TypedDict):
    r"""A function available to an agent.

    See:
    - https://learn.microsoft.com/en-us/azure/ai-services/openai/how-to/function-calling
    """

    name: str
    r"""The name of the function/tool call."""
    description: str
    r"""The description of the tool."""
    parameters: Any
    r"""The JSON Schema of parameters of the function/tool call."""


class ToolFunction(BaseModel):
    r"""A function available to an agent.

    See:
    - https://learn.microsoft.com/en-us/azure/ai-services/openai/how-to/function-calling
    """

    name: str
    r"""The name of the function/tool call."""

    description: str
    r"""The description of the tool."""

    parameters: Any
    r"""The JSON Schema of parameters of the function/tool call."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata
from typing_extensions import Annotated, TypedDict


class BodyOutboundBatchDeleteTypedDict(TypedDict):
    delete_reason: str


class BodyOutboundBatchDelete(BaseModel):
    delete_reason: Annotated[str, FieldMetadata(form=True)]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dialogmessage import DialogMessage, DialogMessageTypedDict
from .dialogrole import DialogRole
from .dialogtoolcall import DialogToolCall, DialogToolCallTypedDict
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionMessageTypedDict(TypedDict):
    role: DialogRole
    r"""Role of dialog"""
    dialog: DialogMessageTypedDict
    tool_calls: List[DialogToolCallTypedDict]
    r"""Tool calls"""
    timestamp: datetime
    r"""Message timestamp"""


class SessionMessage(BaseModel):
    role: DialogRole
    r"""Role of dialog"""

    dialog: DialogMessage

    tool_calls: List[DialogToolCall]
    r"""Tool calls"""

    timestamp: datetime
    r"""Message timestamp"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class CreateTakeoutResponseTypedDict(TypedDict):
    job_id: str
    created_at: datetime


class CreateTakeoutResponse(BaseModel):
    job_id: str

    created_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class UserDeleteRequestTypedDict(TypedDict):
    r"""Request model to delete a user."""

    email: str
    r"""The email address of the user to delete"""
    reason: str
    r"""The reason for deleting the user"""


class UserDeleteRequest(BaseModel):
    r"""Request model to delete a user."""

    email: str
    r"""The email address of the user to delete"""

    reason: str
    r"""The reason for deleting the user"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DashboardTypedDict(TypedDict):
    r"""Deprecated.  Please update to use DashboardTokenResponse.
    Basic information about a dashboard.
    """

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""
    guest_token: str
    r"""Superset guest token of the dashboard"""
    name: str
    r"""Name of the dashboard"""
    superset_url: str
    r"""Superset URL of the dashboard"""


class Dashboard(BaseModel):
    r"""Deprecated.  Please update to use DashboardTokenResponse.
    Basic information about a dashboard.
    """

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""

    guest_token: str
    r"""Superset guest token of the dashboard"""

    name: str
    r"""Name of the dashboard"""

    superset_url: str
    r"""Superset URL of the dashboard"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channelconfigview import ChannelConfigView, ChannelConfigViewTypedDict
from .channelservices import ChannelServices
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChannelTypedDict(TypedDict):
    name: str
    r"""The channel name"""
    channel_service: ChannelServices
    r"""The communication service for a channel."""
    id: int
    r"""The channel ID"""
    supported_modes: NotRequired[Nullable[str]]
    r"""The comma-delimited list of supported modes for the channel, which defines the       possible communication methods for channel targets linked to it."""
    is_system_channel: NotRequired[bool]
    r"""Whether the channel is a built-in system channel (i.e., is not customizable)"""
    config: NotRequired[Nullable[ChannelConfigViewTypedDict]]
    r"""Configuration for the channel"""


class Channel(BaseModel):
    name: str
    r"""The channel name"""

    channel_service: ChannelServices
    r"""The communication service for a channel."""

    id: int
    r"""The channel ID"""

    supported_modes: OptionalNullable[str] = UNSET
    r"""The comma-delimited list of supported modes for the channel, which defines the       possible communication methods for channel targets linked to it."""

    is_system_channel: Optional[bool] = True
    r"""Whether the channel is a built-in system channel (i.e., is not customizable)"""

    config: OptionalNullable[ChannelConfigView] = UNSET
    r"""Configuration for the channel"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["supported_modes", "is_system_channel", "config"]
        nullable_fields = ["supported_modes", "config"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .permissionresponse import PermissionResponse, PermissionResponseTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PermissionGroupResponseTypedDict(TypedDict):
    r"""Information about a group of permissions related to the same feature."""

    name: str
    r"""Name of the permission group"""
    description: str
    r"""Description of the permission group"""
    permissions: List[PermissionResponseTypedDict]
    r"""Permissions in the group"""


class PermissionGroupResponse(BaseModel):
    r"""Information about a group of permissions related to the same feature."""

    name: str
    r"""Name of the permission group"""

    description: str
    r"""Description of the permission group"""

    permissions: List[PermissionResponse]
    r"""Permissions in the group"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class AgentToolFieldDefaultTypedDict(TypedDict):
    r"""Agent-level value for a static parameter on a tool, overriding the tool-level default if one
    exists.
    """

    field_name: str
    r"""The name of the field"""
    default_value: Any
    r"""The default value for the field"""


class AgentToolFieldDefault(BaseModel):
    r"""Agent-level value for a static parameter on a tool, overriding the tool-level default if one
    exists.
    """

    field_name: str
    r"""The name of the field"""

    default_value: Any
    r"""The default value for the field"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sessionaction import SessionAction, SessionActionTypedDict
from .sessiontext import SessionText, SessionTextTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionTranscriptionResponseTypedDict(TypedDict):
    r"""Text transcript of a given session. For more information, see
    [Console docs](https://docs.syllable.ai/workspaces/Sessions).
    """

    session_id: str
    r"""Internal ID of the session"""
    transcription: List[SessionTextTypedDict]
    r"""Transcriptions of all messages in the session"""
    actions: List[SessionActionTypedDict]
    r"""Tool invocations that occurred during the session"""


class SessionTranscriptionResponse(BaseModel):
    r"""Text transcript of a given session. For more information, see
    [Console docs](https://docs.syllable.ai/workspaces/Sessions).
    """

    session_id: str
    r"""Internal ID of the session"""

    transcription: List[SessionText]
    r"""Transcriptions of all messages in the session"""

    actions: List[SessionAction]
    r"""Tool invocations that occurred during the session"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .promptllmconfig import PromptLlmConfig, PromptLlmConfigTypedDict
from .toolresponse import ToolResponse, ToolResponseTypedDict
import pydantic
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PromptResponseTypedDict(TypedDict):
    r"""Response model for prompt operations.
    A prompt defines the behavior of an agent by delivering instructions to the LLM about how the
    agent should behave. A prompt can be linked to one or more agents. A prompt can also be linked to
    tools to allow an agent using it to use those tools. For more information, see
    [Console docs](https://docs.syllable.ai/Resources/Prompts).
    """

    name: str
    r"""The prompt name"""
    type: str
    r"""The type of the prompt"""
    llm_config: PromptLlmConfigTypedDict
    r"""LLM configuration for a prompt."""
    id: int
    r"""The internal ID of the prompt"""
    last_updated: Nullable[str]
    r"""The last updated date of the prompt"""
    description: NotRequired[Nullable[str]]
    r"""The description of the prompt"""
    context: NotRequired[Nullable[str]]
    r"""The prompt text that will be sent to the LLM at the beginning of the conversation"""
    tools: NotRequired[List[str]]
    r"""Names of the tools to which the prompt has access (DEPRECATED - use information from full tools field instead)"""
    edit_comments: NotRequired[Nullable[str]]
    r"""The comments for the most recent edit to the prompt"""
    last_updated_by: NotRequired[Nullable[str]]
    r"""Email address of the user who most recently updated the prompt"""
    agent_count: NotRequired[Nullable[int]]
    r"""The number of agents using the prompt"""
    version_number: NotRequired[Nullable[int]]
    r"""The version number of the current version of the prompt"""
    tools_full: NotRequired[Nullable[List[ToolResponseTypedDict]]]
    r"""Full definitions of tools to which the prompt has access"""


class PromptResponse(BaseModel):
    r"""Response model for prompt operations.
    A prompt defines the behavior of an agent by delivering instructions to the LLM about how the
    agent should behave. A prompt can be linked to one or more agents. A prompt can also be linked to
    tools to allow an agent using it to use those tools. For more information, see
    [Console docs](https://docs.syllable.ai/Resources/Prompts).
    """

    name: str
    r"""The prompt name"""

    type: str
    r"""The type of the prompt"""

    llm_config: PromptLlmConfig
    r"""LLM configuration for a prompt."""

    id: int
    r"""The internal ID of the prompt"""

    last_updated: Nullable[str]
    r"""The last updated date of the prompt"""

    description: OptionalNullable[str] = UNSET
    r"""The description of the prompt"""

    context: OptionalNullable[str] = UNSET
    r"""The prompt text that will be sent to the LLM at the beginning of the conversation"""

    tools: Annotated[
        Optional[List[str]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Names of the tools to which the prompt has access (DEPRECATED - use information from full tools field instead)"""

    edit_comments: OptionalNullable[str] = UNSET
    r"""The comments for the most recent edit to the prompt"""

    last_updated_by: OptionalNullable[str] = UNSET
    r"""Email address of the user who most recently updated the prompt"""

    agent_count: OptionalNullable[int] = UNSET
    r"""The number of agents using the prompt"""

    version_number: OptionalNullable[int] = UNSET
    r"""The version number of the current version of the prompt"""

    tools_full: OptionalNullable[List[ToolResponse]] = UNSET
    r"""Full definitions of tools to which the prompt has access"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "context",
            "tools",
            "edit_comments",
            "last_updated_by",
            "agent_count",
            "version_number",
            "tools_full",
        ]
        nullable_fields = [
            "description",
            "context",
            "edit_comments",
            "last_updated",
            "last_updated_by",
            "agent_count",
            "version_number",
            "tools_full",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ChannelProperties(str, Enum):
    r"""Names of channel fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    NAME = "name"
    NAME_EXACT = "name_exact"
    CHANNEL_SERVICE = "channel_service"
    SUPPORTED_MODES = "supported_modes"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .agenttooldefaults import AgentToolDefaults, AgentToolDefaultsTypedDict
from .custommessageresponse import CustomMessageResponse, CustomMessageResponseTypedDict
from .languagegroupresponse import LanguageGroupResponse, LanguageGroupResponseTypedDict
from .promptresponse import PromptResponse, PromptResponseTypedDict
from .toolresponse import ToolResponse, ToolResponseTypedDict
from datetime import datetime
import pydantic
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Dict, List, Optional, TYPE_CHECKING
from typing_extensions import Annotated, NotRequired, TypedDict

if TYPE_CHECKING:
    from .channeltargetresponse import (
        ChannelTargetResponse,
        ChannelTargetResponseTypedDict,
    )


class AgentResponseTypedDict(TypedDict):
    r"""Response model for agent operations.
    When a user interacts with the Syllable system, they do so by communicating with an agent.
    An agent is linked to a prompt, a custom message, and one or more channel targets to define its
    behavior and capabilities. For more information, see
    [Console docs](https://docs.syllable.ai/workspaces/Agents).
    """

    name: str
    r"""The agent name"""
    type: str
    r"""The agent type. Must be \"ca_v1\" currently."""
    prompt_id: int
    r"""ID of the prompt associated with the agent"""
    custom_message_id: int
    r"""Internal ID of the custom message that should be delivered at the beginning of a conversation with the agent"""
    timezone: str
    r"""The time zone in which the agent operates"""
    variables: Dict[str, str]
    r"""Custom context variables for the conversation session. Keys should be prefixed with \"vars.\"."""
    tool_headers: Nullable[Dict[str, str]]
    r"""Optional headers to include in tool calls for agent. (It is discouraged to use this field for \"Authorization\" headers, as values here are not encrypted. Instead, set up a service with either basic, bearer, or custom header auth; attach the appropriate tools to that service, and the attached tools will automatically use the auth configured on the service.)"""
    id: int
    r"""Internal ID of the agent"""
    updated_at: datetime
    r"""Timestamp of most recent update"""
    last_updated_by: Nullable[str]
    r"""Email of the user who last updated the agent"""
    description: NotRequired[Nullable[str]]
    r"""The agent description"""
    label: NotRequired[Nullable[str]]
    r"""The agent label (DEPRECATED - use labels instead.)"""
    labels: NotRequired[Nullable[List[str]]]
    r"""The agent labels"""
    language_group_id: NotRequired[Nullable[int]]
    r"""Internal ID of the language group associated with the agent"""
    prompt_tool_defaults: NotRequired[List[AgentToolDefaultsTypedDict]]
    r"""Agent-level static parameter values for the agent's tools, overriding any tool-level defaults"""
    languages: NotRequired[List[str]]
    r"""BCP 47 codes of languages the agent supports. (DEPRECATED - pass an empty list here and use language group ID to link agent to a language group instead.)"""
    agent_initiated: NotRequired[bool]
    r"""Whether the agent initiates conversation with a user after the custom_message is delivered"""
    stt_provider: NotRequired[Nullable[str]]
    r"""Speech-to-text provider for the agent."""
    wait_sound: NotRequired[Nullable[str]]
    r"""Sound to play while waiting for a response from the LLM."""
    prompt: NotRequired[Nullable[PromptResponseTypedDict]]
    r"""The prompt associated with the agent."""
    custom_message: NotRequired[Nullable[CustomMessageResponseTypedDict]]
    r"""The message associated with the agent. Will be delivered as a greeting at the beginning of a conversation."""
    channel_targets: NotRequired[Nullable[List["ChannelTargetResponseTypedDict"]]]
    r"""Channel targets associated with the agent"""
    tools: NotRequired[Nullable[List[ToolResponseTypedDict]]]
    r"""Tools associated with the agent"""
    language_group: NotRequired[Nullable[LanguageGroupResponseTypedDict]]
    r"""The language group associated with the agent"""


class AgentResponse(BaseModel):
    r"""Response model for agent operations.
    When a user interacts with the Syllable system, they do so by communicating with an agent.
    An agent is linked to a prompt, a custom message, and one or more channel targets to define its
    behavior and capabilities. For more information, see
    [Console docs](https://docs.syllable.ai/workspaces/Agents).
    """

    name: str
    r"""The agent name"""

    type: str
    r"""The agent type. Must be \"ca_v1\" currently."""

    prompt_id: int
    r"""ID of the prompt associated with the agent"""

    custom_message_id: int
    r"""Internal ID of the custom message that should be delivered at the beginning of a conversation with the agent"""

    timezone: str
    r"""The time zone in which the agent operates"""

    variables: Dict[str, str]
    r"""Custom context variables for the conversation session. Keys should be prefixed with \"vars.\"."""

    tool_headers: Nullable[Dict[str, str]]
    r"""Optional headers to include in tool calls for agent. (It is discouraged to use this field for \"Authorization\" headers, as values here are not encrypted. Instead, set up a service with either basic, bearer, or custom header auth; attach the appropriate tools to that service, and the attached tools will automatically use the auth configured on the service.)"""

    id: int
    r"""Internal ID of the agent"""

    updated_at: datetime
    r"""Timestamp of most recent update"""

    last_updated_by: Nullable[str]
    r"""Email of the user who last updated the agent"""

    description: OptionalNullable[str] = UNSET
    r"""The agent description"""

    label: Annotated[
        OptionalNullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = UNSET
    r"""The agent label (DEPRECATED - use labels instead.)"""

    labels: OptionalNullable[List[str]] = UNSET
    r"""The agent labels"""

    language_group_id: OptionalNullable[int] = UNSET
    r"""Internal ID of the language group associated with the agent"""

    prompt_tool_defaults: Optional[List[AgentToolDefaults]] = None
    r"""Agent-level static parameter values for the agent's tools, overriding any tool-level defaults"""

    languages: Annotated[
        Optional[List[str]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""BCP 47 codes of languages the agent supports. (DEPRECATED - pass an empty list here and use language group ID to link agent to a language group instead.)"""

    agent_initiated: Optional[bool] = False
    r"""Whether the agent initiates conversation with a user after the custom_message is delivered"""

    stt_provider: OptionalNullable[str] = UNSET
    r"""Speech-to-text provider for the agent."""

    wait_sound: OptionalNullable[str] = UNSET
    r"""Sound to play while waiting for a response from the LLM."""

    prompt: OptionalNullable[PromptResponse] = UNSET
    r"""The prompt associated with the agent."""

    custom_message: OptionalNullable[CustomMessageResponse] = UNSET
    r"""The message associated with the agent. Will be delivered as a greeting at the beginning of a conversation."""

    channel_targets: OptionalNullable[List["ChannelTargetResponse"]] = UNSET
    r"""Channel targets associated with the agent"""

    tools: OptionalNullable[List[ToolResponse]] = UNSET
    r"""Tools associated with the agent"""

    language_group: OptionalNullable[LanguageGroupResponse] = UNSET
    r"""The language group associated with the agent"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "label",
            "labels",
            "language_group_id",
            "prompt_tool_defaults",
            "languages",
            "agent_initiated",
            "stt_provider",
            "wait_sound",
            "prompt",
            "custom_message",
            "channel_targets",
            "tools",
            "language_group",
        ]
        nullable_fields = [
            "description",
            "label",
            "labels",
            "language_group_id",
            "tool_headers",
            "stt_provider",
            "wait_sound",
            "last_updated_by",
            "prompt",
            "custom_message",
            "channel_targets",
            "tools",
            "language_group",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentSttProvider(str, Enum):
    r"""Speech-to-text providers supported by agents."""

    GOOGLE_STT_V2_CHIRP_2_ = "Google STT V2 (Chirp 2)"
    DEEPGRAM_NOVA_3 = "Deepgram Nova 3"
    GOOGLE_STT_V2 = "Google STT V2"
    GOOGLE_STT_V1 = "Google STT V1"
    DEEPGRAM_NOVA_2 = "Deepgram Nova 2"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioNumberUpdateRequestTypedDict(TypedDict):
    r"""Request model for updating a Twilio number and associating it with a channel."""

    friendly_name: str
    r"""Friendly name for the Twilio number"""
    phone_sid: str
    r"""Twilio number SID"""


class TwilioNumberUpdateRequest(BaseModel):
    r"""Request model for updating a Twilio number and associating it with a channel."""

    friendly_name: str
    r"""Friendly name for the Twilio number"""

    phone_sid: str
    r"""Twilio number SID"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class InsightsToolDeleteRequestTypedDict(TypedDict):
    tool_id: int


class InsightsToolDeleteRequest(BaseModel):
    tool_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .agenttoolfielddefault import AgentToolFieldDefault, AgentToolFieldDefaultTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AgentToolDefaultsTypedDict(TypedDict):
    r"""Agent-level static parameter values for a tool, overriding any tool-level defaults."""

    tool_name: str
    r"""The name of the tool"""
    default_values: List[AgentToolFieldDefaultTypedDict]
    r"""The default values for fields used in the tool"""


class AgentToolDefaults(BaseModel):
    r"""Agent-level static parameter values for a tool, overriding any tool-level defaults."""

    tool_name: str
    r"""The name of the tool"""

    default_values: List[AgentToolFieldDefault]
    r"""The default values for fields used in the tool"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceGender(str, Enum):
    r"""Gender for an agent voice."""

    FEMALE = "female"
    MALE = "male"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class InsightToolInputTypedDict(TypedDict):
    r"""Request model to create/update an insight tool configuration."""

    name: str
    r"""Human readable name of insight tool"""
    description: str
    r"""Text description of insight tool configuration"""
    version: int
    r"""Version number of insight tool configuration"""
    tool_arguments: Any
    r"""Arguments for calling the insight tool"""
    insight_tool_definition_id: int
    r"""Internal ID for the definition used by the insight tool configuration"""


class InsightToolInput(BaseModel):
    r"""Request model to create/update an insight tool configuration."""

    name: str
    r"""Human readable name of insight tool"""

    description: str
    r"""Text description of insight tool configuration"""

    version: int
    r"""Version number of insight tool configuration"""

    tool_arguments: Any
    r"""Arguments for calling the insight tool"""

    insight_tool_definition_id: int
    r"""Internal ID for the definition used by the insight tool configuration"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .custommessagerule import CustomMessageRule, CustomMessageRuleTypedDict
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CustomMessageCreateRequestTypedDict(TypedDict):
    r"""Request model to create a custom message."""

    name: str
    r"""The name of the custom message"""
    text: str
    r"""The default message that the agent will deliver if no rules are set or no rules match the current timestamp."""
    label: NotRequired[Nullable[str]]
    r"""The label of the custom message"""
    rules: NotRequired[List[CustomMessageRuleTypedDict]]
    r"""Rules for time-specific message variants"""
    type: NotRequired[str]
    r"""Type of the custom message (must be \"greeting\" for now)"""


class CustomMessageCreateRequest(BaseModel):
    r"""Request model to create a custom message."""

    name: str
    r"""The name of the custom message"""

    text: str
    r"""The default message that the agent will deliver if no rules are set or no rules match the current timestamp."""

    label: OptionalNullable[str] = UNSET
    r"""The label of the custom message"""

    rules: Optional[List[CustomMessageRule]] = None
    r"""Rules for time-specific message variants"""

    type: Optional[str] = "greeting"
    r"""Type of the custom message (must be \"greeting\" for now)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["label", "rules", "type"]
        nullable_fields = ["label"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceVarName(str, Enum):
    r"""The variable name of an agent voice (used when processing messages)."""

    OPENAI_ALLOY = "openai:alloy"
    OPENAI_ASH = "openai:ash"
    OPENAI_CORAL = "openai:coral"
    OPENAI_ECHO = "openai:echo"
    OPENAI_FABLE = "openai:fable"
    OPENAI_NOVA = "openai:nova"
    OPENAI_ONYX = "openai:onyx"
    OPENAI_SAGE = "openai:sage"
    OPENAI_SHIMMER = "openai:shimmer"
    ELEVENLABS_ALICE = "elevenlabs:Alice"
    ELEVENLABS_BILL = "elevenlabs:Bill"
    ELEVENLABS_BRIAN = "elevenlabs:Brian"
    ELEVENLABS_CALLUM = "elevenlabs:Callum"
    ELEVENLABS_CHARLIE = "elevenlabs:Charlie"
    ELEVENLABS_CHARLOTTE = "elevenlabs:Charlotte"
    ELEVENLABS_CHRIS = "elevenlabs:Chris"
    ELEVENLABS_DANIEL = "elevenlabs:Daniel"
    ELEVENLABS_ERIC = "elevenlabs:Eric"
    ELEVENLABS_GEORGE = "elevenlabs:George"
    ELEVENLABS_JESSICA = "elevenlabs:Jessica"
    ELEVENLABS_LAURA = "elevenlabs:Laura"
    ELEVENLABS_LIAM = "elevenlabs:Liam"
    ELEVENLABS_LILY = "elevenlabs:Lily"
    ELEVENLABS_MATILDA = "elevenlabs:Matilda"
    ELEVENLABS_RIVER = "elevenlabs:River"
    ELEVENLABS_ROGER = "elevenlabs:Roger"
    ELEVENLABS_SARAH = "elevenlabs:Sarah"
    ELEVENLABS_WILL = "elevenlabs:Will"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_ACHERNAR = "wavenet:female/en-US-Chirp3-HD-Achernar"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_ACHERNAR = "wavenet:female/ko-KR-Chirp3-HD-Achernar"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_ACHERNAR = (
        "wavenet:female/cmn-CN-Chirp3-HD-Achernar"
    )
    WAVENET_FEMALE_ES_US_CHIRP3_HD_ACHERNAR = "wavenet:female/es-US-Chirp3-HD-Achernar"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_ACHERNAR = "wavenet:female/th-TH-Chirp3-HD-Achernar"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_ACHERNAR = "wavenet:female/vi-VN-Chirp3-HD-Achernar"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_AOEDE = "wavenet:female/en-US-Chirp3-HD-Aoede"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_AOEDE = "wavenet:female/ko-KR-Chirp3-HD-Aoede"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_AOEDE = "wavenet:female/cmn-CN-Chirp3-HD-Aoede"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_AOEDE = "wavenet:female/es-US-Chirp3-HD-Aoede"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_AOEDE = "wavenet:female/th-TH-Chirp3-HD-Aoede"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_AOEDE = "wavenet:female/vi-VN-Chirp3-HD-Aoede"
    WAVENET_MALE_ES_US_NEURAL2_B = "wavenet:male/es-US-Neural2-B"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/en-US-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/ko-KR-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/cmn-CN-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_ES_US_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/es-US-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/th-TH-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/vi-VN-Chirp3-HD-Callirrhoe"
    )
    WAVENET_MALE_EN_US_CHIRP3_HD_CHARON = "wavenet:male/en-US-Chirp3-HD-Charon"
    WAVENET_MALE_KO_KR_CHIRP3_HD_CHARON = "wavenet:male/ko-KR-Chirp3-HD-Charon"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_CHARON = "wavenet:male/cmn-CN-Chirp3-HD-Charon"
    WAVENET_MALE_ES_US_CHIRP3_HD_CHARON = "wavenet:male/es-US-Chirp3-HD-Charon"
    WAVENET_MALE_TH_TH_CHIRP3_HD_CHARON = "wavenet:male/th-TH-Chirp3-HD-Charon"
    WAVENET_MALE_VI_VN_CHIRP3_HD_CHARON = "wavenet:male/vi-VN-Chirp3-HD-Charon"
    WAVENET_FEMALE_EN_US_NEURAL2_F = "wavenet:female/en-US-Neural2-F"
    WAVENET_MALE_EN_US_CHIRP3_HD_FENRIR = "wavenet:male/en-US-Chirp3-HD-Fenrir"
    WAVENET_MALE_KO_KR_CHIRP3_HD_FENRIR = "wavenet:male/ko-KR-Chirp3-HD-Fenrir"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_FENRIR = "wavenet:male/cmn-CN-Chirp3-HD-Fenrir"
    WAVENET_MALE_ES_US_CHIRP3_HD_FENRIR = "wavenet:male/es-US-Chirp3-HD-Fenrir"
    WAVENET_MALE_TH_TH_CHIRP3_HD_FENRIR = "wavenet:male/th-TH-Chirp3-HD-Fenrir"
    WAVENET_MALE_VI_VN_CHIRP3_HD_FENRIR = "wavenet:male/vi-VN-Chirp3-HD-Fenrir"
    WAVENET_FEMALE_ES_US_NEURAL2_A = "wavenet:female/es-US-Neural2-A"
    WAVENET_MALE_EN_US_NEURAL2_D = "wavenet:male/en-US-Neural2-D"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_KORE = "wavenet:female/en-US-Chirp3-HD-Kore"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_KORE = "wavenet:female/ko-KR-Chirp3-HD-Kore"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_KORE = "wavenet:female/cmn-CN-Chirp3-HD-Kore"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_KORE = "wavenet:female/es-US-Chirp3-HD-Kore"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_KORE = "wavenet:female/th-TH-Chirp3-HD-Kore"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_KORE = "wavenet:female/vi-VN-Chirp3-HD-Kore"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_LEDA = "wavenet:female/en-US-Chirp3-HD-Leda"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_LEDA = "wavenet:female/ko-KR-Chirp3-HD-Leda"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_LEDA = "wavenet:female/cmn-CN-Chirp3-HD-Leda"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_LEDA = "wavenet:female/es-US-Chirp3-HD-Leda"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_LEDA = "wavenet:female/th-TH-Chirp3-HD-Leda"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_LEDA = "wavenet:female/vi-VN-Chirp3-HD-Leda"
    WAVENET_FEMALE_CMN_TW_WAVENET_A = "wavenet:female/cmn-TW-Wavenet-A"
    WAVENET_MALE_EN_US_NEURAL2_J = "wavenet:male/en-US-Neural2-J"
    WAVENET_FEMALE_YUE_HK_STANDARD_C = "wavenet:female/yue-HK-Standard-C"
    WAVENET_FEMALE_EN_US_STUDIO_O = "wavenet:female/en-US-Studio-O"
    WAVENET_MALE_EN_US_CHIRP3_HD_ORUS = "wavenet:male/en-US-Chirp3-HD-Orus"
    WAVENET_MALE_KO_KR_CHIRP3_HD_ORUS = "wavenet:male/ko-KR-Chirp3-HD-Orus"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_ORUS = "wavenet:male/cmn-CN-Chirp3-HD-Orus"
    WAVENET_MALE_ES_US_CHIRP3_HD_ORUS = "wavenet:male/es-US-Chirp3-HD-Orus"
    WAVENET_MALE_TH_TH_CHIRP3_HD_ORUS = "wavenet:male/th-TH-Chirp3-HD-Orus"
    WAVENET_MALE_VI_VN_CHIRP3_HD_ORUS = "wavenet:male/vi-VN-Chirp3-HD-Orus"
    WAVENET_MALE_EN_US_CHIRP3_HD_PUCK = "wavenet:male/en-US-Chirp3-HD-Puck"
    WAVENET_MALE_KO_KR_CHIRP3_HD_PUCK = "wavenet:male/ko-KR-Chirp3-HD-Puck"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_PUCK = "wavenet:male/cmn-CN-Chirp3-HD-Puck"
    WAVENET_MALE_ES_US_CHIRP3_HD_PUCK = "wavenet:male/es-US-Chirp3-HD-Puck"
    WAVENET_MALE_TH_TH_CHIRP3_HD_PUCK = "wavenet:male/th-TH-Chirp3-HD-Puck"
    WAVENET_MALE_VI_VN_CHIRP3_HD_PUCK = "wavenet:male/vi-VN-Chirp3-HD-Puck"
    WAVENET_FEMALE_KO_KR_NEURAL2_A = "wavenet:female/ko-KR-Neural2-A"
    WAVENET_FEMALE_VI_VN_NEURAL2_A = "wavenet:female/vi-VN-Neural2-A"
    WAVENET_MALE_EN_US_CHIRP3_HD_UMBRIEL = "wavenet:male/en-US-Chirp3-HD-Umbriel"
    WAVENET_MALE_KO_KR_CHIRP3_HD_UMBRIEL = "wavenet:male/ko-KR-Chirp3-HD-Umbriel"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_UMBRIEL = "wavenet:male/cmn-CN-Chirp3-HD-Umbriel"
    WAVENET_MALE_ES_US_CHIRP3_HD_UMBRIEL = "wavenet:male/es-US-Chirp3-HD-Umbriel"
    WAVENET_MALE_TH_TH_CHIRP3_HD_UMBRIEL = "wavenet:male/th-TH-Chirp3-HD-Umbriel"
    WAVENET_MALE_VI_VN_CHIRP3_HD_UMBRIEL = "wavenet:male/vi-VN-Chirp3-HD-Umbriel"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/en-US-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/ko-KR-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/cmn-CN-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_ES_US_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/es-US-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/th-TH-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/vi-VN-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_EN_US_CHIRP3_HD_ZEPHYR = "wavenet:female/en-US-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_ZEPHYR = "wavenet:female/ko-KR-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_ZEPHYR = "wavenet:female/cmn-CN-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_ZEPHYR = "wavenet:female/es-US-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_ZEPHYR = "wavenet:female/th-TH-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_ZEPHYR = "wavenet:female/vi-VN-Chirp3-HD-Zephyr"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .daysofweek import DaysOfWeek
from datetime import datetime
import pydantic
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class OutboundCampaignTypedDict(TypedDict):
    campaign_name: str
    r"""Human readable name of campaign"""
    campaign_variables: Dict[str, str]
    r"""Variables for campaign"""
    caller_id: Nullable[str]
    r"""Caller ID for call"""
    active_days: List[DaysOfWeek]
    r"""Days of the week when campaign is active"""
    id: int
    r"""Unique ID for campaign"""
    last_updated_by: str
    r"""Email of user who last updated campaign"""
    description: NotRequired[Nullable[str]]
    r"""Description of campaign"""
    label: NotRequired[Nullable[str]]
    r"""Label for campaign (DEPRECATED - use labels instead)"""
    labels: NotRequired[Nullable[List[str]]]
    r"""Labels for campaign"""
    daily_start_time: NotRequired[Nullable[str]]
    r"""Start time of campaign each day"""
    daily_end_time: NotRequired[Nullable[str]]
    r"""End time of campaign each day"""
    source: NotRequired[Nullable[str]]
    r"""Source phone number, email, or SMS number"""
    hourly_rate: NotRequired[int]
    r"""Target number of outreach calls per hour"""
    retry_count: NotRequired[int]
    r"""Number of retries per target"""
    retry_interval: NotRequired[Nullable[str]]
    r"""How long to wait before retrying"""
    agent_id: NotRequired[Nullable[int]]
    r"""ID of agent assigned to campaign"""
    created_at: NotRequired[datetime]
    r"""Timestamp of campaign creation"""
    updated_at: NotRequired[datetime]
    r"""Timestamp of campaign update"""


class OutboundCampaign(BaseModel):
    campaign_name: str
    r"""Human readable name of campaign"""

    campaign_variables: Dict[str, str]
    r"""Variables for campaign"""

    caller_id: Nullable[str]
    r"""Caller ID for call"""

    active_days: List[DaysOfWeek]
    r"""Days of the week when campaign is active"""

    id: int
    r"""Unique ID for campaign"""

    last_updated_by: str
    r"""Email of user who last updated campaign"""

    description: OptionalNullable[str] = UNSET
    r"""Description of campaign"""

    label: Annotated[
        OptionalNullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = UNSET
    r"""Label for campaign (DEPRECATED - use labels instead)"""

    labels: OptionalNullable[List[str]] = UNSET
    r"""Labels for campaign"""

    daily_start_time: OptionalNullable[str] = UNSET
    r"""Start time of campaign each day"""

    daily_end_time: OptionalNullable[str] = UNSET
    r"""End time of campaign each day"""

    source: OptionalNullable[str] = UNSET
    r"""Source phone number, email, or SMS number"""

    hourly_rate: Optional[int] = 1
    r"""Target number of outreach calls per hour"""

    retry_count: Optional[int] = 0
    r"""Number of retries per target"""

    retry_interval: OptionalNullable[str] = UNSET
    r"""How long to wait before retrying"""

    agent_id: OptionalNullable[int] = UNSET
    r"""ID of agent assigned to campaign"""

    created_at: Optional[datetime] = None
    r"""Timestamp of campaign creation"""

    updated_at: Optional[datetime] = None
    r"""Timestamp of campaign update"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "label",
            "labels",
            "daily_start_time",
            "daily_end_time",
            "source",
            "hourly_rate",
            "retry_count",
            "retry_interval",
            "agent_id",
            "created_at",
            "updated_at",
        ]
        nullable_fields = [
            "description",
            "label",
            "labels",
            "daily_start_time",
            "daily_end_time",
            "source",
            "caller_id",
            "retry_interval",
            "agent_id",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .toolparametertransform import (
    ToolParameterTransform,
    ToolParameterTransformTypedDict,
)
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class ToolParameterDefaultTypedDict(TypedDict):
    r"""The default value for a parameter of a tool call."""

    transform: ToolParameterTransformTypedDict
    r"""A transform to be applied to the value of a tool parameter.

    Either `value` or `format` must be set:
    - `value` is any arbitrary value: string, list or dictionary.
    - `format` is a string composed of other parameters or context variables.
    """


class ToolParameterDefault(BaseModel):
    r"""The default value for a parameter of a tool call."""

    transform: ToolParameterTransform
    r"""A transform to be applied to the value of a tool parameter.

    Either `value` or `format` must be set:
    - `value` is any arbitrary value: string, list or dictionary.
    - `format` is a string composed of other parameters or context variables.
    """



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LatencyCategory(str, Enum):
    TTS = "tts"
    STT = "stt"
    LLM = "llm"
    TOOL = "tool"
    HTTP = "http"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioPhoneNumberTypedDict(TypedDict):
    sid: str
    r"""The unique identifier for the phone number."""
    phone_number: str
    r"""The phone number."""
    friendly_name: str
    r"""A user-friendly name for the number."""
    trunk_sid: str
    r"""Associated trunk SID, if any."""


class TwilioPhoneNumber(BaseModel):
    sid: str
    r"""The unique identifier for the phone number."""

    phone_number: str
    r"""The phone number."""

    friendly_name: str
    r"""A user-friendly name for the number."""

    trunk_sid: str
    r"""Associated trunk SID, if any."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .useractivitystatus import UserActivityStatus
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing_extensions import NotRequired, TypedDict


class UserResponseTypedDict(TypedDict):
    r"""Information about a user."""

    email: str
    r"""Email address of the user"""
    role_id: int
    r"""ID of the role assigned to the user"""
    id: int
    r"""Internal ID of the user"""
    role_name: str
    r"""Name of the role assigned to the user"""
    email_sent: bool
    r"""Whether the welcome email has been sent to the user"""
    activity_status: UserActivityStatus
    last_updated: datetime
    r"""The timestamp of the most recent update to the user"""
    first_name: NotRequired[Nullable[str]]
    r"""First name of the user"""
    last_name: NotRequired[Nullable[str]]
    r"""Last name of the user"""
    last_updated_comments: NotRequired[Nullable[str]]
    r"""Comments for the most recent edit to the user."""
    last_updated_by: NotRequired[Nullable[str]]
    r"""The email address of the user who last updated the user"""
    last_session_at: NotRequired[Nullable[datetime]]
    r"""The timestamp of the user's last session"""


class UserResponse(BaseModel):
    r"""Information about a user."""

    email: str
    r"""Email address of the user"""

    role_id: int
    r"""ID of the role assigned to the user"""

    id: int
    r"""Internal ID of the user"""

    role_name: str
    r"""Name of the role assigned to the user"""

    email_sent: bool
    r"""Whether the welcome email has been sent to the user"""

    activity_status: UserActivityStatus

    last_updated: datetime
    r"""The timestamp of the most recent update to the user"""

    first_name: OptionalNullable[str] = UNSET
    r"""First name of the user"""

    last_name: OptionalNullable[str] = UNSET
    r"""Last name of the user"""

    last_updated_comments: OptionalNullable[str] = UNSET
    r"""Comments for the most recent edit to the user."""

    last_updated_by: OptionalNullable[str] = UNSET
    r"""The email address of the user who last updated the user"""

    last_session_at: OptionalNullable[datetime] = UNSET
    r"""The timestamp of the user's last session"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "first_name",
            "last_name",
            "last_updated_comments",
            "last_updated_by",
            "last_session_at",
        ]
        nullable_fields = [
            "first_name",
            "last_name",
            "last_updated_comments",
            "last_updated_by",
            "last_session_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .agentsttprovider import AgentSttProvider
from .agenttooldefaults import AgentToolDefaults, AgentToolDefaultsTypedDict
from .agentwaitsound import AgentWaitSound
import pydantic
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AgentCreateTypedDict(TypedDict):
    r"""Request model to create an agent."""

    name: str
    r"""The agent name"""
    type: str
    r"""The agent type. Must be \"ca_v1\" currently."""
    prompt_id: int
    r"""ID of the prompt associated with the agent"""
    custom_message_id: int
    r"""Internal ID of the custom message that should be delivered at the beginning of a conversation with the agent"""
    timezone: str
    r"""The time zone in which the agent operates"""
    variables: Dict[str, str]
    r"""Custom context variables for the conversation session. Keys should be prefixed with \"vars.\"."""
    tool_headers: Nullable[Dict[str, str]]
    r"""Optional headers to include in tool calls for agent. (It is discouraged to use this field for \"Authorization\" headers, as values here are not encrypted. Instead, set up a service with either basic, bearer, or custom header auth; attach the appropriate tools to that service, and the attached tools will automatically use the auth configured on the service.)"""
    description: NotRequired[Nullable[str]]
    r"""The agent description"""
    label: NotRequired[Nullable[str]]
    r"""The agent label (DEPRECATED - use labels instead.)"""
    labels: NotRequired[Nullable[List[str]]]
    r"""The agent labels"""
    language_group_id: NotRequired[Nullable[int]]
    r"""Internal ID of the language group associated with the agent"""
    prompt_tool_defaults: NotRequired[List[AgentToolDefaultsTypedDict]]
    r"""Agent-level static parameter values for the agent's tools, overriding any tool-level defaults"""
    languages: NotRequired[List[str]]
    r"""BCP 47 codes of languages the agent supports. (DEPRECATED - pass an empty list here and use language group ID to link agent to a language group instead.)"""
    agent_initiated: NotRequired[bool]
    r"""Whether the agent initiates conversation with a user after the custom message is delivered"""
    stt_provider: NotRequired[Nullable[AgentSttProvider]]
    r"""Speech-to-text provider for the agent."""
    wait_sound: NotRequired[Nullable[AgentWaitSound]]
    r"""Sound to play while waiting for a response from the LLM."""


class AgentCreate(BaseModel):
    r"""Request model to create an agent."""

    name: str
    r"""The agent name"""

    type: str
    r"""The agent type. Must be \"ca_v1\" currently."""

    prompt_id: int
    r"""ID of the prompt associated with the agent"""

    custom_message_id: int
    r"""Internal ID of the custom message that should be delivered at the beginning of a conversation with the agent"""

    timezone: str
    r"""The time zone in which the agent operates"""

    variables: Dict[str, str]
    r"""Custom context variables for the conversation session. Keys should be prefixed with \"vars.\"."""

    tool_headers: Nullable[Dict[str, str]]
    r"""Optional headers to include in tool calls for agent. (It is discouraged to use this field for \"Authorization\" headers, as values here are not encrypted. Instead, set up a service with either basic, bearer, or custom header auth; attach the appropriate tools to that service, and the attached tools will automatically use the auth configured on the service.)"""

    description: OptionalNullable[str] = UNSET
    r"""The agent description"""

    label: Annotated[
        OptionalNullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = UNSET
    r"""The agent label (DEPRECATED - use labels instead.)"""

    labels: OptionalNullable[List[str]] = UNSET
    r"""The agent labels"""

    language_group_id: OptionalNullable[int] = UNSET
    r"""Internal ID of the language group associated with the agent"""

    prompt_tool_defaults: Optional[List[AgentToolDefaults]] = None
    r"""Agent-level static parameter values for the agent's tools, overriding any tool-level defaults"""

    languages: Annotated[
        Optional[List[str]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""BCP 47 codes of languages the agent supports. (DEPRECATED - pass an empty list here and use language group ID to link agent to a language group instead.)"""

    agent_initiated: Optional[bool] = False
    r"""Whether the agent initiates conversation with a user after the custom message is delivered"""

    stt_provider: OptionalNullable[AgentSttProvider] = UNSET
    r"""Speech-to-text provider for the agent."""

    wait_sound: OptionalNullable[AgentWaitSound] = UNSET
    r"""Sound to play while waiting for a response from the LLM."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "label",
            "labels",
            "language_group_id",
            "prompt_tool_defaults",
            "languages",
            "agent_initiated",
            "stt_provider",
            "wait_sound",
        ]
        nullable_fields = [
            "description",
            "label",
            "labels",
            "language_group_id",
            "tool_headers",
            "stt_provider",
            "wait_sound",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .requeststatus import RequestStatus
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class InsightsTypedDict(TypedDict):
    pass


class Insights(BaseModel):
    pass


class CommunicationRequestResultTypedDict(TypedDict):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""
    target: str
    r"""Target phone number"""
    request_variables: Dict[str, str]
    r"""Variables for request"""
    channel_manager_sid: NotRequired[Nullable[str]]
    r"""Channel manager SID"""
    created_at: NotRequired[datetime]
    r"""Timestamp of request creation"""
    sent_at: NotRequired[Nullable[datetime]]
    r"""Timestamp at which request was sent"""
    attempt_count: NotRequired[int]
    r"""Number of attempts for request"""
    session_id: NotRequired[Nullable[int]]
    r"""Unique ID for call session"""
    conversation_id: NotRequired[Nullable[int]]
    r"""Unique ID for conversation"""
    request_status: NotRequired[RequestStatus]
    r"""Status of a communication request."""
    channel_manager_status: NotRequired[Nullable[str]]
    r"""Status of request in channel manager"""
    insights_status: NotRequired[Nullable[str]]
    r"""Status of session in insight workflow"""
    insights: NotRequired[Nullable[InsightsTypedDict]]
    r"""Insights from call"""


class CommunicationRequestResult(BaseModel):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""

    target: str
    r"""Target phone number"""

    request_variables: Dict[str, str]
    r"""Variables for request"""

    channel_manager_sid: OptionalNullable[str] = UNSET
    r"""Channel manager SID"""

    created_at: Optional[datetime] = None
    r"""Timestamp of request creation"""

    sent_at: OptionalNullable[datetime] = UNSET
    r"""Timestamp at which request was sent"""

    attempt_count: Optional[int] = 0
    r"""Number of attempts for request"""

    session_id: OptionalNullable[int] = UNSET
    r"""Unique ID for call session"""

    conversation_id: OptionalNullable[int] = UNSET
    r"""Unique ID for conversation"""

    request_status: Optional[RequestStatus] = None
    r"""Status of a communication request."""

    channel_manager_status: OptionalNullable[str] = UNSET
    r"""Status of request in channel manager"""

    insights_status: OptionalNullable[str] = UNSET
    r"""Status of session in insight workflow"""

    insights: OptionalNullable[Insights] = UNSET
    r"""Insights from call"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "channel_manager_sid",
            "created_at",
            "sent_at",
            "attempt_count",
            "session_id",
            "conversation_id",
            "request_status",
            "channel_manager_status",
            "insights_status",
            "insights",
        ]
        nullable_fields = [
            "channel_manager_sid",
            "sent_at",
            "session_id",
            "conversation_id",
            "channel_manager_status",
            "insights_status",
            "insights",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DashboardResponseTypedDict(TypedDict):
    r"""Basic information about a dashboard with a description."""

    name: str
    r"""Name of the dashboard"""
    display_name: str
    r"""Display name of the dashboard"""
    rank: int
    r"""Dashboard importance (0 is the highest)"""
    label: str
    r"""Dashboard label. Typically \"report\" or \"dashboard\" """


class DashboardResponse(BaseModel):
    r"""Basic information about a dashboard with a description."""

    name: str
    r"""Name of the dashboard"""

    display_name: str
    r"""Display name of the dashboard"""

    rank: int
    r"""Dashboard importance (0 is the highest)"""

    label: str
    r"""Dashboard label. Typically \"report\" or \"dashboard\" """



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from syllable_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET_SENTINEL
from syllable_sdk.utils import validate_const
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ToolParameterTransformConditionTypedDict(TypedDict):
    r"""A condition to be met for a transform to be applied to the value of a tool parameter."""

    key: str
    r"""The name of the parameter to check."""
    value: str
    r"""The value to check against the parameter."""
    operator: Nullable[Literal["eq"]]
    r"""The operator to use for the comparison. Currently only supports \"eq\" """


class ToolParameterTransformCondition(BaseModel):
    r"""A condition to be met for a transform to be applied to the value of a tool parameter."""

    key: str
    r"""The name of the parameter to check."""

    value: str
    r"""The value to check against the parameter."""

    OPERATOR: Annotated[
        Annotated[
            OptionalNullable[Literal["eq"]], AfterValidator(validate_const("eq"))
        ],
        pydantic.Field(alias="operator"),
    ] = "eq"
    r"""The operator to use for the comparison. Currently only supports \"eq\" """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["operator"]
        nullable_fields = ["operator"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
